#!/bin/zsh

# ---------------------------------------------------------
# This script must be passed a list of archived bunch names
# ---------------------------------------------------------
if [[ $# -eq 0 ]] ; then
	echo 'ERROR: This script must be passed a list of archived bunch names'
	exit 0
fi

# Get the Bunch app name to control (we may be using the beta app)
appname=$(./fetchAppname.sh)

# Get the path where the bunches are stored
strBunchPath=$(osascript -e "tell application \"$appname\" to get preference \"Folder\"" | sed 's/^file:\/\///')

# Generate an array of the archived bunches
arrBunches=(${(f)"$(echo $@)"})

# Get a count of the archived bunches so we know when to stop outputting a comma in the JSON
intLastPos=$((${#arrBunches[*]}))

# Build the opening JSON
echo '{"items": ['

# Process each bunch as an entry in the JSON 'items' array
for bunch in $arrBunches; do
	echo -e '\t{'
	
	# Ouput simple properties
	echo -e "\t\t\"uid\": \"$bunch\","
	echo -e "\t\t\"arg\": \"$bunch\","
	echo -e "\t\t\"autocomplete\": \"$bunch\","
	
	# Output the title - there may be one specified in the bunch file
	strTitle=$(cat $strBunchPath$bunch._bunch | egrep "^title: " | sed "s/title: //")
	if [[ "$strTitle" == "" ]]
	then
		strTitle=$bunch # Default to bunch base file name if no title specified
	fi
	echo -e "\t\t\"title\": \"$strTitle\","
	
	# Output icon
	echo -e "\t\t\"icon\":"
	echo -e "\t\t{"
	echo -e "\t\t\t\"path\": \"./archive.png\""
	echo -e "\t\t}"
	
	# If it is the last bunch, there's no trailing comma
	if [[ "$bunch" == "$arrBunches[$intLastPos]" ]]
	then
		echo -e "\t}"
	else
		echo -e "\t},"
	fi
done

# Build the closing JSON
echo "]}"